@@ -117,7 +117,7 @@ st_shadow_unref (StShadow *shadow)
  * compare non-identically if they differ only by floating point rounding
  * errors.
  *
- * Return value: %TRUE if the two shadows are identical
+ * Returns: %TRUE if the two shadows are identical
  */
 gboolean
 st_shadow_equal (StShadow *shadow,
@@ -216,6 +216,13 @@ st_shadow_helper_new (StShadow     *shadow)
   return helper;
 }
 
+/**
+ * st_shadow_helper_update:
+ * @helper: a #StShadowHelper
+ * @source: a #ClutterActor
+ *
+ * Update @helper from @source.
+ */
 void
 st_shadow_helper_update (StShadowHelper *helper,
                          ClutterActor   *source)
@@ -276,6 +283,7 @@ st_shadow_helper_free (StShadowHelper *helper)
 /**
  * st_shadow_helper_paint:
  * @helper: a #StShadowHelper
+ * @framebuffer: a #CoglFramebuffer
  * @actor_box: the bounding box of the shadow
  * @paint_opacity: the opacity at which the shadow is painted
  *
@@ -284,10 +292,12 @@ st_shadow_helper_free (StShadowHelper *helper)
  */
 void
 st_shadow_helper_paint (StShadowHelper  *helper,
+                        CoglFramebuffer *framebuffer,
                         ClutterActorBox *actor_box,
                         guint8           paint_opacity)
 {
   _st_paint_shadow_with_opacity (helper->shadow,
+                                 framebuffer,
                                  helper->pipeline,
                                  actor_box,
                                  paint_opacity);
