@@ -118,16 +118,23 @@ st_theme_context_class_init (StThemeContextClass *klass)
   /**
    * StThemeContext:scale-factor:
    *
-   * The scaling factor used or high dpi scaling.
+   * The scaling factor used for HiDPI scaling.
    */
   g_object_class_install_property (object_class,
                                    PROP_SCALE_FACTOR,
                                    g_param_spec_int ("scale-factor",
                                                      "Scale factor",
-                                                     "Integer scale factor used for high dpi scaling",
+                                                     "Integer scale factor used for HiDPI scaling",
                                                      0, G_MAXINT, 1,
                                                      ST_PARAM_READWRITE));
 
+  /**
+   * StThemeContext::changed:
+   * @self: a #StThemeContext
+   *
+   * Emitted when the icon theme, font, resolution, scale factor or the current
+   * theme's custom stylesheets change.
+   */
   signals[CHANGED] =
     g_signal_new ("changed",
                   G_TYPE_FROM_CLASS (klass),
@@ -214,6 +221,8 @@ st_theme_context_get_property (GObject    *object,
  * This can be useful in testing scenarios, or if using StThemeContext
  * with something other than #ClutterActor objects, but you generally
  * should use st_theme_context_get_for_stage() instead.
+ *
+ * Returns: (transfer full): a new #StThemeContext
  */
 StThemeContext *
 st_theme_context_new (void)
@@ -296,7 +305,7 @@ on_icon_theme_changed (StTextureCache *cache,
  *
  * Gets a singleton theme context associated with the stage.
  *
- * Return value: (transfer none): the singleton theme context for the stage
+ * Returns: (transfer none): the singleton theme context for the stage
  */
 StThemeContext *
 st_theme_context_get_for_stage (ClutterStage *stage)
@@ -320,6 +329,7 @@ st_theme_context_get_for_stage (ClutterStage *stage)
 /**
  * st_theme_context_set_theme:
  * @context: a #StThemeContext
+ * @theme: a #StTheme
  *
  * Sets the default set of theme stylesheets for the context. This theme will
  * be used for the root node and for nodes descending from it, unless some other
@@ -358,7 +368,7 @@ st_theme_context_set_theme (StThemeContext          *context,
  *
  * Gets the default theme for the context. See st_theme_context_set_theme()
  *
- * Return value: (transfer none): the default theme for the context
+ * Returns: (transfer none): the default theme for the context
  */
 StTheme *
 st_theme_context_get_theme (StThemeContext *context)
@@ -376,7 +386,7 @@ st_theme_context_get_theme (StThemeContext *context)
  * Sets the default font for the theme context. This is the font that
  * is inherited by the root node of the tree of theme nodes. If the
  * font is not overriden, then this font will be used. If the font is
- * partially modified (for example, with 'font-size: 110%', then that
+ * partially modified (for example, with 'font-size: 110%'), then that
  * modification is based on this font.
  */
 void
@@ -401,7 +411,7 @@ st_theme_context_set_font (StThemeContext             *context,
  *
  * Gets the default font for the theme context. See st_theme_context_set_font().
  *
- * Return value: the default font for the theme context.
+ * Returns: the default font for the theme context.
  */
 const PangoFontDescription *
 st_theme_context_get_font (StThemeContext *context)
@@ -419,7 +429,7 @@ st_theme_context_get_font (StThemeContext *context)
  * context. For the node tree associated with a stage, this node represents
  * styles applied to the stage itself.
  *
- * Return value: (transfer none): the root node of the context's style tree
+ * Returns: (transfer none): the root node of the context's style tree
  */
 StThemeNode *
 st_theme_context_get_root_node (StThemeContext *context)
@@ -439,7 +449,7 @@ st_theme_context_get_root_node (StThemeContext *context)
  * Return an existing node matching @node, or if that isn't possible,
  * @node itself.
  *
- * Return value: (transfer none): a node with the same properties as @node
+ * Returns: (transfer none): a node with the same properties as @node
  */
 StThemeNode *
 st_theme_context_intern_node (StThemeContext *context,
@@ -461,7 +471,7 @@ st_theme_context_intern_node (StThemeContext *context,
  *
  * Return the current scale factor of @context.
  *
- * Return value: a scale factor
+ * Returns: an integer scale factor
  */
 int
 st_theme_context_get_scale_factor (StThemeContext *context)
